The tools in this module take a vector or matrix as input and return a vector or matrix that contains a subset of the points in the input 
vector/matrix that have been chosen in some systematic way.  These tools were developed to be used in conjuction with the tools in the 
[dimred](module_dimred.md) module.  However, the landmark selection algorithms in this module may also find an application in some other 
context.
